@@ -11,7 +11,6 @@ import PyOfficeRobot
 from office.lib.decorator_utils.instruction_url import instruction
 
 
-
 @instruction
 def send_message(who: str, message: str):
     PyOfficeRobot.chat.send_message(who, message)
@@ -32,6 +31,10 @@ def send_file(who, file):
     PyOfficeRobot.file.send_file(who, file)
 
 
+def group_send():
+    PyOfficeRobot.group.send()
+
+
 # 保存指定人的消息
 # BY：盖飞
 @instruction
